@@ -1,8 +1,8 @@
 package Cassandra::Client;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::VERSION = '0.13_005'; # TRIAL
+$Cassandra::Client::VERSION = '0.13_006'; # TRIAL
 
-$Cassandra::Client::VERSION = '0.13005';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
+$Cassandra::Client::VERSION = '0.13006';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
 
 use 5.010;
 use strict;
@@ -84,6 +84,11 @@ sub _connect {
     return _cb($callback) if $self->{connected};
     return _cb($callback, 'Cannot connect: shutdown() has been called') if $self->{shutdown};
 
+    # This is ONLY useful if the user doesn't throw away the C::C object on connect errors.
+    if (!$self->{connecting} && $self->{throttler}->should_fail()) {
+        return _cb($callback, "Client-induced connection failure by throttling mechanism");
+    }
+
     push @{$self->{connect_callbacks}||=[]}, $callback;
     if ($self->{connecting}++) {
         return;
@@ -121,6 +126,7 @@ sub _connect {
             },
         ], sub {
             my $error= shift;
+            $self->{throttler}->count($error);
             if ($error) {
                 $last_error= "On $contact_point: $error";
                 return $next_connect->();
@@ -228,9 +234,6 @@ sub _command {
         start_time => Time::HiRes::time(),
     };
 
-    # Handle overloads
-    goto FAILFAST if $self->{throttler}->should_fail();
-
     goto OVERFLOW if $self->{active_queries} >= $self->{options}{max_concurrent_queries};
 
     goto SLOWPATH if !$self->{connected};
@@ -238,6 +241,8 @@ sub _command {
     my $connection= $self->{pool}->get_one;
     goto SLOWPATH if !$connection;
 
+    goto FAILFAST if $self->{throttler}->should_fail();
+
     $self->{active_queries}++;
     $connection->$command(sub {
         my ($error, $result)= @_;
@@ -276,9 +281,6 @@ sub _command_slowpath {
             $self->{pool}->get_one_cb($next);
         }, sub {
             my ($next, $connection)= @_;
-            # Yes, if we immediately take the slow path, which we would if we're not connected, we're going to throttle twice
-            # For now, I'm okay with that, but let's mark it with a TODO anyway.
-            # XXX
             if ($self->{throttler}->should_fail()) {
                 return $next->("Client-induced failure by throttling mechanism");
             }
@@ -524,7 +526,7 @@ Cassandra::Client - Perl library for accessing Cassandra using its binary networ
 
 =head1 VERSION
 
-version 0.13_005
+version 0.13_006
 
 =head1 DESCRIPTION
 
